@@ -52,9 +52,19 @@ class PanelCredentialAttribute:
     PASSWORD = "pswd"
 
 
+class PanelUpdateAttribute:
+    """Panel update attributes."""
+
+    AVAILABLE = "av"
+    AVAILABLE_VERSION = "asv"
+    CURRENT_VERSION = "csv"
+    UPDATE_REASON = "rsn"
+
+
 class SystemAttribute:
     """System attributes."""
 
+    ADMIN = "ad"
     PANEL_ID = "panid"
     PARTITION = "par"
     PARTITION_ID = "parid"
@@ -90,6 +100,7 @@ class VivintDeviceAttribute:
     CAPABILITY = "ca"
     CAPABILITY_CATEGORY = "caca"
     CURRENT_SOFTWARE_VERSION = "csv"
+    FEATURES = "fea"
     FIRMWARE_VERSION = "fwv"
     HIDDEN = "hidden"
     ID = "_id"
@@ -120,6 +131,7 @@ class CameraAttribute(VivintDeviceAttribute):
     CAMERA_DIRECT_AVAILABLE = "cda"
     CAMERA_DIRECT_STREAM_PATH = "cdp"
     CAMERA_DIRECT_STREAM_PATH_STANDARD = "cdps"
+    CAMERA_EXTEND_CHIME_ENABLED = "cex"
     CAMERA_IP_ADDRESS = "caip"
     CAMERA_IP_PORT = "cap"
     CAMERA_MAC = "cmac"
