@@ -5,7 +5,14 @@ from typing import TYPE_CHECKING, Type
 
 from ..const import VivintDeviceAttribute as Attribute
 from ..entity import Entity
-from ..enums import CapabilityCategoryType, CapabilityType, DeviceType, ZoneBypass
+from ..enums import (
+    CapabilityCategoryType,
+    CapabilityType,
+    DeviceType,
+    FeatureType,
+    ZoneBypass,
+)
+from ..utils import send_deprecation_warning
 from ..vivintskyapi import VivintSkyApi
 from ..zjs_device_config_db import get_zwave_device_info
 
@@ -59,12 +66,23 @@ class VivintDevice(Entity):
             if (caca := data.get(Attribute.CAPABILITY_CATEGORY)) is not None
             else None
         )
+        self._features = (
+            [FeatureType(feature) for feature in feats if feats.get(feature) is True]
+            if (feats := data.get(Attribute.FEATURES)) is not None
+            else None
+        )
         self._parent: VivintDevice | None = None
 
     def __repr__(self) -> str:
         """Return custom __repr__ of device."""
         return f"<{self.__class__.__name__} {self.id}, {self.name}>"
 
+    @property
+    def api(self) -> VivintSkyApi:
+        """Return the API."""
+        assert self.alarm_panel, """no alarm panel set for this device"""
+        return self.alarm_panel.system.api
+
     @property
     def id(self) -> int:  # pylint: disable=invalid-name
         """Device's id."""
@@ -101,6 +119,11 @@ class VivintDevice(Entity):
         """Return the device type."""
         return DeviceType(self.data.get(Attribute.TYPE))
 
+    @property
+    def features(self) -> list[FeatureType] | None:
+        """Device Features."""
+        return self._features
+
     @property
     def has_battery(self) -> bool:
         """Return `True` if the device has battery details."""
@@ -167,8 +190,8 @@ class VivintDevice(Entity):
     @property
     def vivintskyapi(self) -> VivintSkyApi:
         """Instance of VivintSkyApi."""
-        assert self.alarm_panel, """no alarm panel set for this device"""
-        return self.alarm_panel.system.vivintskyapi
+        send_deprecation_warning("vivintskyapi", "api")
+        return self.api
 
     def get_zwave_details(self) -> None:
         """Get Z-Wave details."""
