@@ -1,7 +1,8 @@
 """Module that implements the Switch class."""
 from __future__ import annotations
 
-from ..const import SwitchAttribute, ZWaveDeviceAttribute
+from ..const import SwitchAttribute as Attribute
+from ..utils import send_deprecation_warning
 from . import VivintDevice
 
 
@@ -11,17 +12,23 @@ class Switch(VivintDevice):
     @property
     def is_on(self) -> bool:
         """Return True if switch is on."""
-        return bool(self.data[SwitchAttribute.STATE])
+        return bool(self.data[Attribute.STATE])
+
+    @property
+    def is_online(self) -> bool:
+        """Return True if switch is online."""
+        return bool(self.data[Attribute.ONLINE])
 
     @property
     def level(self) -> int:
         """Return the level of the switch betwen 0..100."""
-        return int(self.data[SwitchAttribute.VALUE])
+        return int(self.data[Attribute.VALUE])
 
     @property
     def node_online(self) -> bool:
         """Return True if the node is online."""
-        return bool(self.data[ZWaveDeviceAttribute.ONLINE])
+        send_deprecation_warning("node_online", "is_online")
+        return self.is_online
 
     async def set_state(
         self,
@@ -30,7 +37,7 @@ class Switch(VivintDevice):
     ) -> None:
         """Set switch's state."""
         assert self.alarm_panel
-        await self.vivintskyapi.set_switch_state(
+        await self.api.set_switch_state(
             self.alarm_panel.id, self.alarm_panel.partition_id, self.id, on, level
         )
 
