@@ -1,7 +1,7 @@
 """Module that implements the Entity class."""
 from __future__ import annotations
 
-from typing import Any, Callable
+from collections.abc import Callable
 
 UPDATE = "update"
 
@@ -9,17 +9,17 @@ UPDATE = "update"
 class Entity:
     """Describe a Vivint entity."""
 
-    def __init__(self, data: dict[str, Any]):
+    def __init__(self, data: dict):
         """Initialize an entity."""
         self.__data = data
         self._listeners: dict[str, list[Callable]] = {}
 
     @property
-    def data(self) -> dict[str, Any]:
+    def data(self) -> dict:
         """Return entity's raw data as returned by VivintSky API."""
         return self.__data
 
-    def update_data(self, new_val: dict[str, Any], override: bool = False) -> None:
+    def update_data(self, new_val: dict, override: bool = False) -> None:
         """Update entity's raw data."""
         if override:
             self.__data = new_val
@@ -32,7 +32,9 @@ class Entity:
         """Handle a pubnub message directed to this entity."""
         self.update_data(message)
 
-    def on(self, event_name: str, callback: Callable) -> Callable:
+    def on(  # pylint: disable=invalid-name
+        self, event_name: str, callback: Callable
+    ) -> Callable:
         """Register an event callback."""
         listeners: list = self._listeners.setdefault(event_name, [])
         listeners.append(callback)
@@ -49,5 +51,5 @@ class Entity:
         for listener in self._listeners.get(event_name, []):
             try:
                 listener(data)
-            except:  # noqa E722
+            except:  # noqa E722 # pylint: disable=bare-except
                 pass
