@@ -5,10 +5,12 @@ import json
 import logging
 import ssl
 from collections.abc import Callable
-from typing import Any
+from http.cookies import Morsel, SimpleCookie
+from typing import Any, cast
 
 import aiohttp
 import certifi
+import grpc
 from aiohttp import ClientResponseError
 from aiohttp.client import _RequestContextManager
 
@@ -24,11 +26,13 @@ from .exceptions import (
     VivintSkyApiError,
     VivintSkyApiMfaRequiredError,
 )
+from .proto import beam_pb2, beam_pb2_grpc
 
 _LOGGER = logging.getLogger(__name__)
 
-VIVINT_API_ENDPOINT = "https://www.vivintsky.com/api"
-VIVINT_MFA_ENDPOINT = (
+API_ENDPOINT = "https://www.vivintsky.com/api"
+BEAM_ENDPOINT = "beam.vivintsky.com:443"
+MFA_ENDPOINT = (
     "https://www.vivintsky.com/platform-user-api/v0/platformusers/2fa/validate"
 )
 
@@ -51,10 +55,14 @@ class VivintSkyApi:
         self.__has_custom_client_session = client_session is not None
         self.__mfa_pending = False
 
+    def _get_session_cookie(self) -> Morsel | None:
+        """Get the session cookie."""
+        cookie = self.__client_session.cookie_jar.filter_cookies(API_ENDPOINT)
+        return cast(SimpleCookie, cookie).get("s")
+
     def is_session_valid(self) -> bool:
         """Return the state of the current session."""
-        cookies = self.__client_session.cookie_jar.filter_cookies(VIVINT_API_ENDPOINT)
-        return cookies.get("s") is not None
+        return self._get_session_cookie() is not None
 
     async def connect(self) -> dict:
         """Connect to VivintSky Cloud Service."""
@@ -75,10 +83,7 @@ class VivintSkyApi:
 
     async def verify_mfa(self, code: str) -> None:
         """Verify multi-factor authentication code."""
-        resp = await self.__post(
-            VIVINT_MFA_ENDPOINT,
-            data=json.dumps({"code": code}),
-        )
+        resp = await self.__post(MFA_ENDPOINT, data=json.dumps({"code": code}))
         if resp is not None:
             self.__mfa_pending = False
 
@@ -114,6 +119,26 @@ class VivintSkyApi:
             raise VivintSkyApiError("Unable to retrieve system data")
         return resp
 
+    async def get_system_update(self, panel_id: int) -> dict:
+        """Get panel software update details."""
+        resp = await self.__get(
+            f"systems/{panel_id}/system-update",
+            headers={"Accept-Encoding": "application/json"},
+        )
+        if not resp:
+            raise VivintSkyApiError("Unable to retrieve system update")
+        return resp
+
+    async def update_panel_software(self, panel_id: int) -> None:
+        """Request a panel software update."""
+        if not await self.__post(f"systems/{panel_id}/system-update"):
+            raise VivintSkyApiError("Unable to update panel software")
+
+    async def reboot_panel(self, panel_id: int) -> None:
+        """Reboot a panel."""
+        if not await self.__post(f"systems/{panel_id}/reboot-panel"):
+            raise VivintSkyApiError("Unable to reboot panel")
+
     async def get_device_data(self, panel_id: int, device_id: int) -> dict:
         """Get the raw data for a device."""
         resp = await self.__get(
@@ -148,6 +173,72 @@ class VivintSkyApi:
             )
             raise VivintSkyApiError("Failed to set alarm state")
 
+    async def trigger_alarm(self, panel_id: int, partition_id: int) -> None:
+        """Trigger an alarm."""
+        if not await self.__post(f"{panel_id}/{partition_id}/alarm"):
+            _LOGGER.error("Failed to trigger alarm for panel %s", panel_id)
+            raise VivintSkyApiError("Failed to trigger alarm")
+
+    async def set_camera_as_doorbell_chime_extender(
+        self, panel_id: int, device_id: int, state: bool
+    ) -> None:
+        """Set the camera to be used as a doorbell chime extender."""
+        creds = grpc.ssl_channel_credentials()
+        assert (cookie := self._get_session_cookie())
+
+        async with grpc.aio.secure_channel(BEAM_ENDPOINT, credentials=creds) as channel:
+            stub: beam_pb2_grpc.BeamStub = beam_pb2_grpc.BeamStub(channel)  # type: ignore
+            response: beam_pb2.SetUseAsDoorbellChimeExtenderResponse = await stub.SetUseAsDoorbellChimeExtender(
+                beam_pb2.SetUseAsDoorbellChimeExtenderRequest(  # pylint: disable=no-member
+                    panel_id=panel_id,
+                    device_id=device_id,
+                    use_as_doorbell_chime_extender=state,
+                ),
+                metadata=[("session", cookie.value)],
+            )
+
+        _LOGGER.debug("Response received: %s", str(response))
+
+    async def set_camera_privacy_mode(
+        self, panel_id: int, device_id: int, state: bool
+    ) -> None:
+        """Set the camera privacy mode."""
+        creds = grpc.ssl_channel_credentials()
+        assert (cookie := self._get_session_cookie())
+
+        async with grpc.aio.secure_channel(BEAM_ENDPOINT, credentials=creds) as channel:
+            stub: beam_pb2_grpc.BeamStub = beam_pb2_grpc.BeamStub(channel)  # type: ignore
+            response: beam_pb2.SetCameraPrivacyModeResponse = (
+                await stub.SetCameraPrivacyMode(
+                    beam_pb2.SetCameraPrivacyModeRequest(  # pylint: disable=no-member
+                        panel_id=panel_id,
+                        device_id=device_id,
+                        privacy_mode=state,
+                    ),
+                    metadata=[("session", cookie.value)],
+                )
+            )
+
+        _LOGGER.debug("Response received: %s", str(response))
+
+    async def set_camera_deter_mode(
+        self, panel_id: int, device_id: int, state: bool
+    ) -> None:
+        """Set the camera deter mode."""
+        creds = grpc.ssl_channel_credentials()
+        assert (cookie := self._get_session_cookie())
+
+        async with grpc.aio.secure_channel(BEAM_ENDPOINT, credentials=creds) as channel:
+            stub: beam_pb2_grpc.BeamStub = beam_pb2_grpc.BeamStub(channel)  # type: ignore
+            response: beam_pb2.SetDeterOverrideResponse = await stub.SetDeterOverride(
+                beam_pb2.SetDeterOverrideRequest(  # pylint: disable=no-member
+                    panel_id=panel_id, device_id=device_id, enabled=state
+                ),
+                metadata=[("session", cookie.value)],
+            )
+
+        _LOGGER.debug("Response received: %s", str(response))
+
     async def set_garage_door_state(
         self, panel_id: int, partition_id: int, device_id: int, state: int
     ) -> None:
@@ -402,13 +493,13 @@ class VivintSkyApi:
         if self.__client_session.closed:
             raise VivintSkyApiError("The client session has been closed")
 
-        is_mfa_request = path == VIVINT_MFA_ENDPOINT
+        is_mfa_request = path == MFA_ENDPOINT
 
         if self.__mfa_pending and not is_mfa_request:
             raise VivintSkyApiMfaRequiredError(AuthenticationResponse.MFA_REQUIRED)
 
         resp = await method(
-            path if is_mfa_request else f"{VIVINT_API_ENDPOINT}/{path}",
+            path if is_mfa_request else f"{API_ENDPOINT}/{path}",
             headers=headers,
             params=params,
             data=data,
@@ -429,6 +520,8 @@ class VivintSkyApi:
                 if message == AuthenticationResponse.MFA_REQUIRED or is_mfa_request:
                     self.__mfa_pending = True
                     raise VivintSkyApiMfaRequiredError(message)
+                if resp.status == 400:
+                    raise VivintSkyApiError(message)
                 raise VivintSkyApiAuthenticationError(message)
             resp.raise_for_status()
             return None
